==> cmsmadesimple-1.6.4.tgz: cms/modules/ThemeManager/lang/ext/et_EE.php <==
<?php
$lang['error_nomenumanager'] = 'Men&uuml;&uuml;halduri moodulit ei leitud';
$lang['active'] = 'Aktiivne';
$lang['default'] = 'Algne';
$lang['prompt_themename'] = 'Ekspordi Teema kui:';
$lang['info_themename'] = 'See v&auml;li m&auml;&auml;rab v&auml;ljastatava teema nime, s&otilde;ltumata teema sisendnimest';
$lang['error_editingproblem'] = 'Probleem teemas viidatud failide puhastamise ja muutmisega.';
$lang['error_problemsavingincludes'] = 'Probleem teemas kodeeritud failide salvestamisega.';
$lang['error_nofilesuploaded'] = '&Uuml;htegi faili ei laetud &uuml;les. Make sure your form tag&#039;s enctype was set to multipart/form-data and that the right field is being checked for the uploaded file.';
$lang['error_templateexists'] = 'Teema nimega &quot;%s&quot; juba eksisteerib';
$lang['error_stylesheetexists'] = 'Stiilileht nimega &quot;%s&quot; juba eksisteerib';
$lang['error_nostylesheets'] = 'Teemas ei leitud &uuml;htegi stiililehte';
$lang['error_couldnotcreatetemplate'] = 'Ei suutnud luua malli definitsiooni';
$lang['error_couldnotassoccss'] = 'Probleem stiililehtede seostamisel malliga';
$lang['error_nooutput'] = 'Ei ole midagi, mida v&auml;ljastada';
$lang['error_notemplate'] = 'Ei suutnud leida malli';
$lang['error_dtdmismatch'] = 'DTD Versiooni sobimatus, ei saa importida';
$lang['import'] = 'Impordi';
$lang['upload'] = 'Lae Teema &Uuml;les';
$lang['id'] = 'ID';
$lang['name'] = 'Nimi';
$lang['export'] = 'Ekspordi';
$lang['submit'] = 'Saada';
$lang['friendlyname'] = 'Teemahaldur';
$lang['postinstall'] = 'M&auml;&auml;ra kindlasti &quot;Manage Themes&quot; &otilde;igus selle mooduli kasutamiseks!';
$lang['uninstalled'] = 'Moodul eemaldatud.';
$lang['installed'] = 'Mooduli versioon %s installeeritud.';
$lang['prefsupdated'] = 'Mooduli eelistused uuendatud.';
$lang['accessdenied'] = 'Ligip&auml;&auml;s keelatud. Palun kontrolli oma &otilde;igusi.';
$lang['error'] = 'Viga!';
$lang['upgraded'] = 'Moodul uuendatud versioonile %s.';
$lang['moddescription'] = 'Moodul sisuteemade (mallide ja stiililehtede) impordiks ja ekspordiks';
$lang['changelog'] = '<ul>
<li>
<p>version 1.0.7, August, 2006</p>
<p>More bug fixes, and split the code into separate files</p>
<p>Version 1.0.6. July, 2006</p>
<p>Fixed handling of javascript (and other files) in the template</p>
<p>Version 1.0.5. January, 2006</p>
<p>Fixed handling for multiple templates in one xml file, added css to template associations in the xml file, fixed some url parsing in css files, and a couple of lang strings (thanks pat)</p>
<p><b>Note:</b> XML files created with older versions of theme manager will <em>again</em> not import.  This is because of the dtd versionin change, and this is a security feature.  Sorry folks.</p>
</li>
<li><p>Version 1.0.4. January, 2006</p>
<p>Ensure we only output the same template, stylsheet, and file once (or make a reasonable effort at it), and added a dtdversion tag to the output.  Also a much stricter permissons model.  Removed the extra debug messages too.</p>
<p><b>Note:</b> XML files created with older versions of theme manager will not import.  This is because of the dtd versioning scheme included, and this is a security feature.  Sorry folks.</p>
</li>
<li><p>Version 1.0.3. January, 2006</p>
<p>Now supports multiple templates in one theme, recursive directory creation, and base64_encodes of all stylesheets and templates</p>
</li>
<li><p>Version 1.0.2. December, 2005</p>
<p>Now handles included images and javascript in both the stylesheets and the templates.  When restoring files are restored to a directory created under uploads/themename.</p></li>
<li>Version 1.0.1. December, 2005 - Fixed dependencies, help, and general cleanup.</li>
<li>Version 1.0.0. 31 November, 2005 - Initial Release.</li>
</ul>';
$lang['help'] = '<h3>Mida see teeb?</h3>
<p>This module allows you to import and export templates and their attached stylesheets as &quot;themes&quot;.  This allows you to share your look and feel with other cms users.</p
<h3>How Do I Use It</h3>
<p>This module has no front end interface, only an admin interface.  It allows you to select an existing (active) template, and click &quot;Export&quot;.  An XML file containing the template and its attached stylesheets will be created and sent you you via download.</p>
<h3>Permissions</h3>
<p>The permissions model is strict for the Theme Manager to ensure database integrity.  The permission &quot;Manage Themes&quot; is required to export themes, and these three permissions (&quot;Add Stylesheets&quot;, &quot;Add StyleSheet Assocations&quot;, and &quot;Add Templates&quot;) are required to be able to import a theme.</p>
<p>As well, the opposite functionality exists, you may upload a theme file (xml format) and have the enclosed templates and stylesheets automatically imported into your cmsms installation.</p>
<h3>Support</h3>
<p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
<ul>
<li>For the latest version of this module, FAQs, or to file a Bug Report or buy commercial support, please visit the module homepage at <a href=&quot;http://dev.cmsmadesimple.org&quot;>dev.cmsmadesimple.org</a>.</li>
<li>Additional discussion of this module may also be found in the <a href=&quot;http://forum.cmsmadesimple.org&quot;>CMS Made Simple Forums</a>.</li>
<li>The author, calguy1000, can often be found in the <a href=&quot;irc://irc.freenode.net/#cms&quot;>CMS IRC Channel</a>.</li>
<li>Lastly, you may have some success emailing the author directly.</li>  
</ul>
<p>As per the GPL, this software is provided as-is. Please read the text
of the license for the full disclaimer.</p>

<h3>Copyright and License</h3>
<p>Copyright &copy; 2005, Robert Campbell <a href=&quot;mailto:calguy1000@hotmail.com&quot;><calguy1000@hotmail.com></a>. All Rights Are Reserved.</p>
<p>This module has been released under the <a href=&quot;http://www.gnu.org/licenses/licenses.html#GPL&quot;>GNU Public License</a>. You must agree to this license before using the module.</p>
';
$lang['utmz'] = '156861353.1157121618.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
$lang['utma'] = '156861353.1526332053.1157121618.1157745950.1157896763.6';
$lang['utmc'] = '156861353';
?>

==> cmsmadesimple-1.9.4p3.tgz: cms/modules/ThemeManager/lang/ext/et_EE.php <==
<?php
$lang['error_uploadpermissions'] = '<strong>HOIATUS:</strong> Sul ei ole piisavalt &otilde;igusi teemade &uuml;leslaadimiseks v&otilde;i paigaldamiseks. See v&otilde;ib olla &uuml;leslaadimiste v&otilde;i moodulite alamkataloogide &otilde;iguste t&otilde;ttu, v&otilde;i su serveril v&otilde;ib olla aktiveeritud Safe mode.';
$lang['error_nomenumanager'] = 'Men&uuml;&uuml;halduri moodulit ei leitud';
$lang['active'] = 'Aktiivne';
$lang['default'] = 'Algne';
$lang['prompt_themename'] = 'Ekspordi Teema kui:';
$lang['info_themename'] = 'See v&auml;li m&auml;&auml;rab v&auml;ljastatava teema nime, s&otilde;ltumata teema sisendnimest';
$lang['error_editingproblem'] = 'Probleem teemas viidatud failide puhastamise ja muutmisega.';
$lang['error_problemsavingincludes'] = 'Probleem teemas kodeeritud failide salvestamisega.';
$lang['error_nofilesuploaded'] = '&Uuml;htegi faili ei laetud &uuml;les. Make sure your form tag&#039;s enctype was set to multipart/form-data and that the right field is being checked for the uploaded file.';
$lang['error_templateexists'] = 'Teema nimega &quot;%s&quot; juba eksisteerib';
$lang['error_stylesheetexists'] = 'Stiilileht nimega &quot;%s&quot; juba eksisteerib';
$lang['error_nostylesheets'] = 'Teemas ei leitud &uuml;htegi stiililehte';
$lang['error_couldnotcreatetemplate'] = 'Ei suutnud luua malli definitsiooni';
$lang['error_couldnotassoccss'] = 'Probleem stiililehtede seostamisel malliga';
$lang['error_nooutput'] = 'Ei ole midagi, mida v&auml;ljastada';
$lang['error_notemplate'] = 'Ei suutnud leida malli';
$lang['error_dtdmismatch'] = 'DTD Versiooni sobimatus, ei saa importida';
$lang['import'] = 'Impordi';
$lang['upload'] = 'Lae Teema &Uuml;les';
$lang['id'] = 'ID';
$lang['name'] = 'Nimi';
$lang['export'] = 'Ekspordi';
$lang['submit'] = 'Saada';
$lang['friendlyname'] = 'Teemahaldur';
$lang['postinstall'] = 'M&auml;&auml;ra kindlasti &quot;Manage Themes&quot; &otilde;igus selle mooduli kasutamiseks!';
$lang['uninstalled'] = 'Moodul eemaldatud.';
$lang['installed'] = 'Mooduli versioon %s installeeritud.';
$lang['prefsupdated'] = 'Mooduli eelistused uuendatud.';
$lang['accessdenied'] = 'Ligip&auml;&auml;s keelatud. Palun kontrolli oma &otilde;igusi.';
$lang['error'] = 'Viga!';
$lang['upgraded'] = 'Moodul uuendatud versioonile %s.';
$lang['moddescription'] = 'Moodul sisuteemade (mallide ja stiililehtede) impordiks ja ekspordiks';
$lang['import_succeeded'] = 'Teema imporditi edukalt';
$lang['help'] = '<h3>What Does This Do?</h3>
<p>This module allows you to import and export templates and their attached stylesheets as &quot;themes&quot;.  This allows you to share your look and feel with other cms users.</p
<h3>How Do I Use It</h3>
<p>This module has no front end interface, only an admin interface.  It allows you to select an existing (active) template, and click &quot;Export&quot;.  An XML file containing the template and its attached stylesheets will be created and sent you you via download.</p>
<h3>Permissions</h3>
<p>The permissions model is strict for the Theme Manager to ensure database integrity.  The permission &quot;Manage Themes&quot; is required to export themes, and these three permissions (&quot;Add Stylesheets&quot;, &quot;Add StyleSheet Assocations&quot;, and &quot;Add Templates&quot;) are required to be able to import a theme.</p>
<p>As well, the opposite functionality exists, you may upload a theme file (xml format) and have the enclosed templates and stylesheets automatically imported into your cmsms installation.</p>
<h3>Support</h3>
<p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
<ul>
<li>For the latest version of this module, FAQs, or to file a Bug Report or buy commercial support, please visit the module homepage at <a href="http://dev.cmsmadesimple.org">dev.cmsmadesimple.org</a>.</li>
<li>Additional discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forums</a>.</li>
<li>The author, calguy1000, can often be found in the <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a>.</li>
<li>Lastly, you may have some success emailing the author directly.</li>  
</ul>
<p>As per the GPL, this software is provided as-is. Please read the text
of the license for the full disclaimer.</p>

<h3>Copyright and License</h3>
<p>Copyright &amp;copy; 2005, Robert Campbell <a href="mailto:calguy1000@hotmail.com">&amp;lt;calguy1000@hotmail.com&amp;gt;</a>. All Rights Are Reserved.</p>
<p>This module has been released under the <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License</a>. You must agree to this license before using the module.</p>
';
$lang['utma'] = '156861353.3215545266732019000.1241091787.1253110943.1253112986.115';
$lang['utmz'] = '156861353.1253112986.115.25.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php/topic,15318.0.html|utmcmd=referral';
$lang['qca'] = '1240683615-58409973-79915303';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>
